import React from "react";
import { ColumnDescription, SearchProps } from "react-bootstrap-table-nextgen";
import ToolkitProvider from "./provider";
export default ToolkitProvider;
export declare const ToolkitContext: {
    Provider: {
        new (props: TableToolkitProps<any>): {
            _: any;
            state: any;
            onSearch(searchText: any): void;
            onClear(): void;
            onColumnToggle(dataField: any): void;
            setDependencyModules(_: any): void;
            render(): React.JSX.Element;
            registerExposedAPI: (tableExposedAPIEmitter: any) => void;
            tableExposedAPIEmitter: any;
            handleExportCSV: (source: any) => void;
            context: unknown;
            setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<any>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<any>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<any>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<any>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<any>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<any>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<any>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<any>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<any>, nextState: Readonly<{}>, nextContext: any): void;
        };
        getDerivedStateFromProps(props: TableToolkitProps<any>, state: any): any;
        contextType?: React.Context<any> | undefined;
    };
    Consumer: React.Consumer<ToolkitContextType>;
};
export { default as ColumnToggle } from "./src/column-toggle";
export { default as CSVExport } from "./src/csv";
export { default as Search } from "./src/search";
/**
 * declaration for table toolkit sub module
 */
export interface InjectedSearchProps {
    searchText: string;
    onSearch: (val: string) => void;
    onClear: () => void;
}
export interface SearchMatchProps<T extends object = any> {
    searchText: string;
    value: string;
    column: ColumnDescription<T>;
    row: T;
}
export interface TableSearchProps<T extends object = any> {
    searchFormatted?: boolean | undefined;
    defaultSearch?: string | undefined;
    placeholder?: string | undefined;
    onColumnMatch?: (props: SearchMatchProps<T>) => boolean;
    customMatchFunc?: ((props: SearchMatchProps<T>) => boolean) | undefined;
    afterSearch?: (newResult: T[]) => void | undefined;
    searchContext?: Function;
    searchText?: string;
}
export interface CSVProps {
    fileName?: string | undefined;
    separator?: string | undefined;
    ignoreHeader?: boolean | undefined;
    ignoreFooter?: boolean | undefined;
    noAutoBOM?: boolean | undefined;
    /**
     * default is text/plain;charset=utf-8
     */
    blobType?: string | undefined;
    exportAll?: boolean | undefined;
    onlyExportSelection?: boolean | undefined;
    onlyExportFiltered?: boolean | undefined;
}
export interface TableToolkitProps<T extends object = any> {
    bootstrap4?: boolean | undefined;
    search?: TableSearchProps<T> | boolean | undefined;
    keyField: keyof T | string;
    data: T[];
    ref?: any;
    columns: Array<ColumnDescription<T>>;
    children: (props: ToolkitContextType) => JSX.Element;
    exportCSV?: boolean | CSVProps | undefined;
    columnToggle?: {
        [dataField: string]: boolean;
    } | boolean | undefined;
    setDependencyModules?: Function;
    registerExposedAPI?: Function;
}
export interface ToolkitContextType {
    searchProps: InjectedSearchProps;
    csvProps: {
        onExport: (source?: any) => void;
    };
    columnToggleProps: {
        columns: ColumnDescription[];
        /**
         * array of toggled columns
         */
        toggles: boolean[];
        onColumnToggle: (dataField: string) => void;
    };
    baseProps: {
        /**
         * table key field
         */
        keyField: any;
        columns: ColumnDescription[];
        data: any[];
        bootstrap4?: boolean | undefined;
    };
}
export interface ToggleListProps {
    columns: ColumnDescription[];
    /**
     * array of toggled columns
     */
    toggles: boolean[];
    onColumnToggle: (dataField: string) => void;
    btnClassName?: string | undefined;
    className?: string | undefined;
    contextual?: string | undefined;
}
export interface ExportCSVButtonProps {
    children: React.ReactNode;
    onExport: () => void;
    style?: React.CSSProperties | undefined;
    className?: string | undefined;
}
export interface SearchBarProps<T = any> extends SearchProps<T> {
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    delay?: number | undefined;
    searchText?: string | undefined;
    tableId?: string | undefined;
    ref?: React.RefObject<React.Component<SearchProps<T>>>;
}
export interface ClearSearchButtonProps {
    onClear?: (() => void) | undefined;
    className?: string | undefined;
    text?: string | undefined;
}
